@@ -13,6 +13,7 @@ class DocumentManager;
 class FavoriteLocationModel;
 class HealthCertificateManager;
 class LiveDataManager;
+class PassManager;
 class PkPassManager;
 class ReservationManager;
 class TransferManager;
@@ -51,15 +52,15 @@ public:
     void setFavoriteLocationModel(FavoriteLocationModel *favLocModel);
     void setLiveDataManager(LiveDataManager *liveDataMgr);
     void setTripGroupManager(TripGroupManager *tripGroupMgr);
+    void setPassManager(PassManager *passMgr);
     void setHealthCertificateManager(HealthCertificateManager *healthCertMgr);
 
     // data import
     void importFromIntent(const KAndroidExtras::Intent &intent);
     Q_INVOKABLE void importFromClipboard();
     Q_INVOKABLE void importFromUrl(const QUrl &url);
-    void importData(const QByteArray &data, const QString &fileName = {});
-
-    Q_INVOKABLE void checkCalendar();
+    Q_INVOKABLE bool importData(const QByteArray &data, const QString &fileName = {});
+    Q_INVOKABLE bool importText(const QString &text);
 
     static ApplicationController* instance();
 
@@ -95,6 +96,8 @@ private:
     bool importHealthCertificateRecursive(const KItinerary::ExtractorDocumentNode &node);
     void importPass(const QString &passId);
     void importMimeMessage(KMime::Message *msg);
+    void importNode(const KItinerary::ExtractorDocumentNode &node);
+    bool importGenericPkPass(const KItinerary::ExtractorDocumentNode &node);
 
     static ApplicationController *s_instance;
 
@@ -105,8 +108,11 @@ private:
     FavoriteLocationModel *m_favLocModel = nullptr;
     LiveDataManager *m_liveDataMgr = nullptr;
     TripGroupManager *m_tripGroupMgr = nullptr;
+    PassManager *m_passMgr = nullptr;
     HealthCertificateManager *m_healthCertMgr = nullptr;
     QNetworkAccessManager *m_nam = nullptr;
+
+    bool m_importLock = false;
 };
 
 #endif // APPLICATIONCONTROLLER_H
