@@ -104,17 +104,24 @@ int HealthCertificateManager::rowCount(const QModelIndex& parent) const
 
 QVariant HealthCertificateManager::data(const QModelIndex &index, int role) const
 {
+    if (!checkIndex(index) || index.row() < 0) {
+        return {};
+    }
+
     const auto &v = m_certificates[index.row()];
     switch (role) {
         case Qt::DisplayRole:
 #if HAVE_KHEALTHCERTIFICATE
             if (v.cert.userType() == qMetaTypeId<KVaccinationCertificate>()) {
                 const auto cert = v.cert.value<KVaccinationCertificate>();
-                return i18n("Vaccination %1/%2 (%3)", cert.dose(), cert.totalDoses(), cert.name());
+                if (cert.dose() > 0 && cert.totalDoses() > 0) {
+                    return i18n("Vaccination %1/%2 (%3)", cert.dose(), cert.totalDoses(), cert.name());
+                }
+                return i18n("Vaccination (%1)", cert.name());
             }
             if (v.cert.userType() == qMetaTypeId<KTestCertificate>()) {
                 const auto cert = v.cert.value<KTestCertificate>();
-                return i18n("Test %1 (%2)", QLocale().toString(cert.date(), QLocale::NarrowFormat), cert.name());
+                return i18n("Test %1 (%2)", QLocale().toString(cert.date().isValid() ? cert.date() : cert.certificateIssueDate().date(), QLocale::NarrowFormat), cert.name());
             }
             if (v.cert.userType() == qMetaTypeId<KRecoveryCertificate>()) {
                 const auto cert = v.cert.value<KRecoveryCertificate>();
@@ -167,7 +174,7 @@ void HealthCertificateManager::loadCertificates()
     endResetModel();
 }
 
-QByteArray HealthCertificateManager::certificateRawData(const CertData &certData) const
+QByteArray HealthCertificateManager::certificateRawData([[maybe_unused]] const CertData &certData) const
 {
 #if HAVE_KHEALTHCERTIFICATE
     if (certData.cert.userType() == qMetaTypeId<KVaccinationCertificate>()) {
@@ -191,7 +198,10 @@ bool HealthCertificateManager::certLessThan(const CertData &lhs, const CertData
     if (lhsDt == rhsDt) {
         return lhs.name < rhs.name;
     }
-    return lhsDt > rhsDt;
+    if (!lhsDt.isValid()) {
+        return false;
+    }
+    return !rhsDt.isValid() || lhsDt > rhsDt;
 #else
     return lhs.name < rhs.name;
 #endif
