@@ -23,6 +23,8 @@ public:
     Q_INVOKABLE QString formatTime(const QVariant &obj, const QString &propertyName) const;
     Q_INVOKABLE QString formatDate(const QVariant &obj, const QString &propertyName) const;
     Q_INVOKABLE QString formatDateTime(const QVariant &obj, const QString &propertyName) const;
+    /** Auto-detect date or date/time, and convert to local time zone. */
+    Q_INVOKABLE QString formatDateOrDateTimeLocal(const QVariant &obj, const QString &propertyName) const;
     Q_INVOKABLE QString formatDuration(int seconds) const;
     Q_INVOKABLE QString formatDistance(int meter) const;
 };
