@@ -53,25 +53,11 @@ static bool needsSplitting(const QVariant &res)
         || JsonLd::isA<RentalCarReservation>(res);
 }
 
-static QTimeZone destinationTimeZone(const QVariant &res)
+static QTimeZone timeZone(const QDateTime &dt)
 {
-    const auto dt = SortUtil::endDateTime(res);
     return dt.timeSpec() == Qt::TimeZone ? dt.timeZone() : QTimeZone();
 }
 
-static GeoCoordinates geoCoordinate(const QVariant &res)
-{
-    if (LocationUtil::isLocationChange(res)) {
-        return LocationUtil::geo(LocationUtil::arrivalLocation(res));
-    }
-    return LocationUtil::geo(LocationUtil::location(res));
-}
-
-static bool isCanceled(const QVariant &res)
-{
-    return JsonLd::canConvert<Reservation>(res) && JsonLd::convert<Reservation>(res).reservationStatus() == Reservation::ReservationCancelled;
-}
-
 TimelineModel::TimelineModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -92,6 +78,7 @@ TimelineModel::TimelineModel(QObject *parent)
     });
 
     connect(&m_currentBatchTimer, &QTimer::timeout, this, &TimelineModel::currentBatchChanged);
+    connect(&m_currentBatchTimer, &QTimer::timeout, this, &TimelineModel::updateTodayMarker);
     connect(&m_currentBatchTimer, &QTimer::timeout, this, &TimelineModel::scheduleCurrentBatchTimer);
     m_currentBatchTimer.setTimerType(Qt::VeryCoarseTimer);
     m_currentBatchTimer.setSingleShot(true);
@@ -119,18 +106,18 @@ void TimelineModel::setReservationManager(ReservationManager* mgr)
     m_resMgr = mgr;
     for (const auto &resId : mgr->batches()) {
         const auto res = m_resMgr->reservation(resId);
-        auto elem = TimelineElement(resId, res, TimelineElement::SelfContained);
+        auto elem = TimelineElement(this, resId, res, TimelineElement::SelfContained);
         if (!elem.isReservation()) { // a type we can't handle
             continue;
         }
         if (needsSplitting(res)) {
-            m_elements.push_back(TimelineElement{resId, res, TimelineElement::RangeBegin});
-            m_elements.push_back(TimelineElement{resId, res, TimelineElement::RangeEnd});
+            m_elements.push_back(TimelineElement{this, resId, res, TimelineElement::RangeBegin});
+            m_elements.push_back(TimelineElement{this, resId, res, TimelineElement::RangeEnd});
         } else {
             m_elements.push_back(std::move(elem));
         }
     }
-    m_elements.push_back(TimelineElement{TimelineElement::TodayMarker, QDateTime(today(), QTime(0, 0))});
+    m_elements.push_back(TimelineElement{this, TimelineElement::TodayMarker,  QDateTime(today(), QTime(0, 0))});
     std::sort(m_elements.begin(), m_elements.end());
 
     connect(mgr, &ReservationManager::batchAdded, this, &TimelineModel::batchAdded);
@@ -140,6 +127,7 @@ void TimelineModel::setReservationManager(ReservationManager* mgr)
     connect(mgr, &ReservationManager::batchRemoved, this, &TimelineModel::batchRemoved);
     endResetModel();
 
+    updateTodayMarker();
     updateInformationElements();
     Q_EMIT todayRowChanged();
 
@@ -214,7 +202,7 @@ QVariant TimelineModel::data(const QModelIndex& index, int role) const
             return elem.elementType;
         case TodayEmptyRole:
             if (elem.elementType == TimelineElement::TodayMarker) {
-                return index.row() == (int)(m_elements.size() - 1) || m_elements.at(index.row() + 1).dt.date() > today();
+                return isDateEmpty(m_elements.at(index.row()).dt.date());
             }
             return {};
         case IsTodayRole:
@@ -259,6 +247,12 @@ QVariant TimelineModel::data(const QModelIndex& index, int role) const
             break;
         case StartDateTimeRole:
             return elem.dt;
+        case EndDateTimeRole:
+            return elem.endDateTime();
+        case IsTimeboxedRole:
+            return elem.isTimeBoxed();
+        case IsCanceledRole:
+            return elem.isCanceled();
     }
     return {};
 }
@@ -291,10 +285,10 @@ void TimelineModel::batchAdded(const QString &resId)
 {
     const auto res = m_resMgr->reservation(resId);
     if (needsSplitting(res)) {
-        insertElement(TimelineElement{resId, res, TimelineElement::RangeBegin});
-        insertElement(TimelineElement{resId, res, TimelineElement::RangeEnd});
+        insertElement(TimelineElement{this, resId, res, TimelineElement::RangeBegin});
+        insertElement(TimelineElement{this, resId, res, TimelineElement::RangeEnd});
     } else {
-        insertElement(TimelineElement{resId, res, TimelineElement::SelfContained});
+        insertElement(TimelineElement{this, resId, res, TimelineElement::SelfContained});
     }
 
     updateInformationElements();
@@ -389,7 +383,7 @@ void TimelineModel::updateElement(const QString &resId, const QVariant &res, Tim
         beginRemoveRows({}, row, row);
         m_elements.erase(it);
         endRemoveRows();
-        insertElement(TimelineElement{resId, res, rangeType});
+        insertElement(TimelineElement{this, resId, res, rangeType});
     } else {
         Q_EMIT dataChanged(index(row, 0), index(row, 0));
     }
@@ -435,15 +429,31 @@ void TimelineModel::dayChanged()
 
 void TimelineModel::updateTodayMarker()
 {
-    const auto it = std::lower_bound(m_elements.begin(), m_elements.end(), today(), [](const auto &lhs, const auto &rhs) {
-        return lhs.dt.date() < rhs;
-    });
+    auto dt = now();
+    auto it = std::lower_bound(m_elements.begin(), m_elements.end(), dt);
+
+    if (it != m_elements.begin()) {
+        const auto prevIt = std::prev(it);
+        // check if the previous element is the old today marker, if so nothing to do
+        if ((*prevIt).elementType == TimelineElement::TodayMarker) {
+            (*prevIt).dt = dt;
+            return;
+        }
+        // check if the previous element is still ongoing, in that case we want to be before that
+        if ((*prevIt).dt.date() == today() && ((*prevIt).isTimeBoxed() && (*prevIt).endDateTime() > now())) {
+            it = prevIt;
+            dt = (*prevIt).dt;
+        }
+    }
+
     const auto newRow = std::distance(m_elements.begin(), it);
     const auto oldRow = todayRow();
-    Q_ASSERT(oldRow < newRow);
+    if (oldRow >= newRow) {
+        return;
+    }
 
     beginInsertRows({}, newRow, newRow);
-    m_elements.insert(it, TimelineElement{TimelineElement::TodayMarker, QDateTime(today(), QTime(0, 0))});
+    m_elements.insert(it, TimelineElement{this, TimelineElement::TodayMarker, dt});
     endInsertRows();
 
     beginRemoveRows({}, oldRow, oldRow);
@@ -474,28 +484,23 @@ void TimelineModel::updateInformationElements()
             continue;
         }
 
-        if (!(*it).isReservation()) {
-            ++it;
-            continue;
-        }
-        const auto res = m_resMgr->reservation((*it).batchId());
-        if (isCanceled(res)) {
+        if ((*it).isCanceled()) {
             ++it;
             continue;
         }
 
         auto newCountry = homeCountry;
-        newCountry.setIsoCode(LocationHelper::destinationCountry(res));
+        newCountry.setIsoCode((*it).destinationCountry());
         newCountry.setTimeZone(previousCountry.timeZone(), (*it).dt);
-        newCountry.setTimeZone(destinationTimeZone(res), (*it).dt);
+        newCountry.setTimeZone(timeZone((*it).endDateTime()), (*it).dt);
         if (newCountry == previousCountry) {
             ++it;
             continue;
         }
         if (!(newCountry == homeCountry) || newCountry.hasRelevantTimeZoneChange(previousCountry)) {
             // for location changes, we want this after the corresponding element
-            const auto dt =  LocationUtil::isLocationChange(res) ? SortUtil::endDateTime(res) : SortUtil::startDateTime(res);
-            it = insertOrUpdate(it, TimelineElement{TimelineElement::LocationInfo, dt, QVariant::fromValue(newCountry)});
+            const auto dt = (*it).isLocationChange() ? (*it).endDateTime() : (*it).dt;
+            it = insertOrUpdate(it, TimelineElement{this, TimelineElement::LocationInfo, dt, QVariant::fromValue(newCountry)});
         }
 
         ++it;
@@ -514,6 +519,12 @@ void TimelineModel::updateWeatherElements()
     qDebug() << "recomputing weather elements";
     GeoCoordinates geo;
 
+    auto date = now();
+    // round to next full hour
+    date.setTime(QTime(date.time().hour(), 0));
+    date = date.addSecs(60 * 60);
+    const auto maxForecastTime = m_weatherMgr->maximumForecastTime(date.date());
+
     // look through the past, clean up weather elements there and figure out where we are
     auto it = m_elements.begin();
     for (; it != m_elements.end() && (*it).dt < now();) {
@@ -525,27 +536,24 @@ void TimelineModel::updateWeatherElements()
             continue;
         }
 
-        if (!(*it).isReservation()) {
+        if ((*it).isCanceled()) {
             ++it;
             continue;
         }
-        const auto res = m_resMgr->reservation((*it).batchId());
-        if (!isCanceled(res)) {
-            const auto newGeo = geoCoordinate(res);
-            if (LocationUtil::isLocationChange(res) || newGeo.isValid()) {
-                geo = newGeo;
+        const auto newGeo = (*it).destinationCoordinates();
+        if ((*it).isLocationChange() || newGeo.isValid()) {
+            geo = newGeo;
+
+            // if we are in an ongoing location change, start afterwards
+            const auto endDt = (*it).endDateTime();
+            if (endDt.isValid() && date < endDt) {
+                date = endDt;
             }
         }
 
         ++it;
     }
 
-    auto date = now();
-    // round to next full hour
-    date.setTime(QTime(date.time().hour(), 0));
-    date = date.addSecs(60 * 60);
-    const auto maxForecastTime = m_weatherMgr->maximumForecastTime(date.date());
-
     while(it != m_elements.end() && date < maxForecastTime) {
 
         if ((*it).dt < date || (*it).elementType == TimelineElement::TodayMarker) {
@@ -562,16 +570,13 @@ void TimelineModel::updateWeatherElements()
             }
 
             // track where we are
-            if (!(*it).isReservation()) {
+            if ((*it).isCanceled()) {
                 ++it;
                 continue;
             }
-            const auto res = m_resMgr->reservation((*it).batchId());
-            if (!isCanceled(res)) {
-                const auto newGeo = geoCoordinate(res);
-                if (LocationUtil::isLocationChange(res) || newGeo.isValid()) {
-                    geo = newGeo;
-                }
+            const auto newGeo = (*it).destinationCoordinates();
+            if ((*it).isLocationChange() || newGeo.isValid()) {
+                geo = newGeo;
             }
 
             ++it;
@@ -587,15 +592,11 @@ void TimelineModel::updateWeatherElements()
             if ((*it2).dt >= endTime) {
                 break;
             }
-            if (!(*it2).isReservation()) {
-                continue;
-            }
-            const auto res = m_resMgr->reservation((*it2).batchId());
-            if (LocationUtil::isLocationChange(res)) {
+            if ((*it2).isLocationChange()) {
                 // exclude the actual travel time from forecast ranges
-                endTime = std::min(endTime, TimelineElement::relevantDateTime(res, TimelineElement::RangeBegin));
-                nextStartTime = std::max(endTime, TimelineElement::relevantDateTime(res, TimelineElement::RangeEnd));
-                newGeo = geoCoordinate(res);
+                endTime = std::min(endTime, (*it2).dt);
+                nextStartTime = std::max(endTime, (*it2).endDateTime());
+                newGeo = (*it2).destinationCoordinates();
                 break;
             }
         }
@@ -609,7 +610,7 @@ void TimelineModel::updateWeatherElements()
 
         // updated or new data
         if (fc.isValid()) {
-            it = insertOrUpdate(it, TimelineElement{TimelineElement::WeatherForecast, date, QVariant::fromValue(fc)});
+            it = insertOrUpdate(it, TimelineElement{this, TimelineElement::WeatherForecast, date, QVariant::fromValue(fc)});
         }
         // we have no forecast data, but a matching weather element: remove
         else if ((*it).elementType == TimelineElement::WeatherForecast && (*it).dt == date) {
@@ -633,7 +634,7 @@ void TimelineModel::updateWeatherElements()
         if (fc.isValid()) {
             const auto row = std::distance(m_elements.begin(), it);
             beginInsertRows({}, row, row);
-            it = m_elements.insert(it, TimelineElement{TimelineElement::WeatherForecast, date, QVariant::fromValue(fc)});
+            it = m_elements.insert(it, TimelineElement{this, TimelineElement::WeatherForecast, date, QVariant::fromValue(fc)});
             ++it;
             endInsertRows();
         }
@@ -690,11 +691,11 @@ void TimelineModel::tripGroupAdded(const QString& groupId)
 {
     const auto g = m_tripGroupManager->tripGroup(groupId);
 
-    TimelineElement beginElem{TimelineElement::TripGroup, g.beginDateTime(), groupId};
+    TimelineElement beginElem{this, TimelineElement::TripGroup, g.beginDateTime(), groupId};
     beginElem.rangeType = TimelineElement::RangeBegin;
     insertElement(std::move(beginElem));
 
-    TimelineElement endElem{TimelineElement::TripGroup, g.endDateTime(), groupId};
+    TimelineElement endElem{this, TimelineElement::TripGroup, g.endDateTime(), groupId};
     endElem.rangeType = TimelineElement::RangeEnd;
     insertElement(std::move(endElem));
 }
@@ -743,7 +744,7 @@ void TimelineModel::transferChanged(const Transfer& transfer)
             --it;
         }
     }
-    insertOrUpdate(it, TimelineElement(transfer));
+    insertOrUpdate(it, TimelineElement(this, transfer));
 
     Q_EMIT todayRowChanged();
 }
@@ -882,15 +883,43 @@ QVariant TimelineModel::locationAtTime(const QDateTime& dt) const
         return {};
     }
 
-    for (--it; it != m_elements.begin(); --it) {
-        if (!(*it).isReservation()) {
-            continue;
+    for (--it ;; --it) {
+        // this is a still ongoing non-location change
+        if (it != m_elements.end() && !(*it).isLocationChange() && (*it).endDateTime().isValid() && (*it).endDateTime() > dt) {
+            if ((*it).isReservation()) {
+                auto loc = LocationUtil::location(m_resMgr->reservation((*it).batchId()));
+                if (LocationUtil::geo(loc).isValid() || !LocationUtil::address(loc).addressCountry().isEmpty()) {
+                    return loc;
+                }
+            }
         }
-        const auto res = m_resMgr->reservation((*it).batchId());
-        if (!LocationUtil::isLocationChange(res)) {
-            continue;
+
+        if ((*it).isReservation() && (*it).isLocationChange()) {
+            // TODO make this work for transfers too
+            const auto res = m_resMgr->reservation((*it).batchId());
+            return LocationUtil::arrivalLocation(res);
+        }
+
+        if (it == m_elements.begin()) {
+            break;
         }
-        return LocationUtil::arrivalLocation(res);
     }
+
     return {};
 }
+
+bool TimelineModel::isDateEmpty(const QDate &date) const
+{
+    auto it = std::lower_bound(m_elements.begin(), m_elements.end(), date, [](const auto &lhs, auto rhs) {
+        return lhs.dt.date() < rhs;
+    });
+    for (; it != m_elements.end(); ++it) {
+        if ((*it).dt.date() == date && (*it).elementType != TimelineElement::TodayMarker) {
+            return false;
+        }
+        if ((*it).dt.date() != date) {
+            break;
+        }
+    }
+    return true;
+}
